import { combineReducers } from 'redux';
import {
  QUEUE_GAME_TO_ADD,
  GAME_PERSISTED,
  ADD_GAME,
  STORE_GAMES,
  START_LOADING,
  RECORD_ERROR,
} from './actions';

export function games(state = [], action) {
  switch (action.type) {
    case STORE_GAMES:
      return action.games;
    case ADD_GAME:
      return [action.game, ...state];
    default:
      return state;
  }
}

export function gamesToAdd(state = {}, action) {
  switch (action.type) {
    case QUEUE_GAME_TO_ADD:
      return {
        [action.game.id]: action.game,
        ...state,
      };
    case GAME_PERSISTED:
      const {
        [action.game.id]: gameToRemove,
        ...gamesToKeep
      } = state;
      return gamesToKeep;
    default:
      return state;
  }
}

export function loading(state = false, action) {
  switch (action.type) {
    case START_LOADING:
      return true;
    case STORE_GAMES:
    case RECORD_ERROR:
      return false;
    default:
      return state;
  }
}

export function error(state = false, action) {
  switch (action.type) {
    case RECORD_ERROR:
      return true;
    case START_LOADING:
    case STORE_GAMES:
      return false;
    default:
      return state;
  }
}

export default combineReducers({
  games,
  gamesToAdd,
  loading,
  error,
});
